Cpp function that calculates convexity of a single feature.
CalcBoundaryConvex(
feature,
windowSize,
stepSize,
fid,
rid,
filename = "",
noRID = TRUE
)A NumericMatrix that holds the data of one feature from the given sf object.
A double describing the diameter of the window used to measure convexity.
A double describing the distance between measurements along an arc.
An integer that holds the current feature id.
A string that holds the unique route ID for the current feature.
A string denoting the name of the file you wish to output convexity data to.
A boolean that denotes whether the given sf object has an RID column.
matrix
Cpp function that takes in a single feature from the given sf object and calculates raw convexity, convexity index, and sinuosity of that feature. It formats convexity data into a NumericMatrix and outputs it.