Assists in the manipulation and processing of linear features with the help of the 'sf' package. Makes use of linear referencing to extract data from most shape files. Reference for this packages methods: Albeke, S.E. et al. (2010) <doi:10.1007/s10980-010-9528-4>.
The function bct takes in an sf object and returns raw convexity,
convexity index, and sinuosity at certain point intervals along a given linear feature.
Currently the only function available is for calculating the convexity of boundaries in a given shp file.
Useful links:
Report bugs at https://gitlab.com/albekeecoinfolab/rlft/-/issues